return {
	-- allow seamless navigation between vim buffers and tmux/wezterm splits
	{
		"numToStr/Navigator.nvim",
		branch = "master",
		config = true,
		event = "VeryLazy",
		keys = {
			{
				"<c-w>h",
				function()
					require("Navigator").left()
				end,
				{ silent = true },
			},
			{
				"<c-w>k",
				function()
					require("Navigator").up()
				end,
				{ silent = true },
			},
			{
				"<c-w>l",
				function()
					require("Navigator").right()
				end,
				{ silent = true },
			},
			{
				"<c-w>j",
				function()
					require("Navigator").down()
				end,
				{ silent = true },
			},
			{
				"<c-w>p",
				function()
					require("Navigator").previous()
				end,
				{ silent = true },
			},
		},
	},
	-- jump between letters with improved fFtT quicksearch, mimics sneak
	{
		"folke/flash.nvim",
		event = "VeryLazy",
		opts = {},
		keys = {
			{
				"s",
				mode = { "n", "x", "o" },
				function()
					require("flash").jump()
				end,
				desc = "Flash",
			},
			{
				"S",
				mode = { "n", "x", "o" },
				function()
					require("flash").treesitter()
				end,
				desc = "Flash Treesitter",
			},
			{
				"r",
				mode = "o",
				function()
					require("flash").remote()
				end,
				desc = "Remote Flash",
			},
			{
				"R",
				mode = { "o", "x" },
				function()
					require("flash").treesitter_search()
				end,
				desc = "Treesitter Search",
			},
			{
				"<c-s>",
				mode = { "c" },
				function()
					require("flash").toggle()
				end,
				desc = "Toggle Flash Search",
			},
		},
	},

	-- personal dict improvements for git sync
	{ "micarmst/vim-spellsync", event = "VeryLazy" },
	{
		"folke/which-key.nvim",
		config = true,
		event = "CursorHold",
	},
	-- collection of plugins
	{
		"echasnovski/mini.nvim",
		version = "*",
		dependencies = { "rktjmp/fwatch.nvim" },
		config = function()
			-- automatic callback to invoke 'mini.base16' when colorscheme file is changed
			local colorsfile = vim.fn.stdpath("state") .. "/colorscheme.lua"
			local function source_colors()
				if vim.fn.filereadable(colorsfile) == 1 then
					vim.cmd("source " .. colorsfile)
				end
			end
			-- set on startup
			source_colors()
			-- continuously watch colors file for changes
			local fwatch = require("fwatch")
			fwatch.watch(colorsfile, {
				on_event = vim.schedule_wrap(function()
					source_colors()
				end),
			})

			require("mini.ai").setup()
			require("mini.comment").setup({
				hooks = {
					pre = function()
						-- use treesitter commentstring functionality if it's installed
						if require("util").is_available("ts_context_commentstring") then
							require("ts_context_commentstring.internal").update_commentstring()
						end
					end,
				},
			})
			require("mini.cursorword").setup({ delay = 500 })
			vim.api.nvim_set_hl(0, "MiniCursorword", { bold = true, underline = false })
			vim.api.nvim_set_hl(0, "MiniCursorwordCurrent", { bold = true, underline = false })
			require("mini.fuzzy").setup()
			require("mini.indentscope").setup({
				symbol = "│",
				draw = { animation = require("mini.indentscope").gen_animation.none() },
				options = { indent_at_cursor = false },
			})
			require("mini.map").setup()
			require("mini.move").setup()
			require("mini.operators").setup()
			require("mini.pairs").setup()
			require("mini.trailspace").setup()
			local starter = require("mini.starter")
			starter.setup({
				evaluate_single = true,
				items = {
					starter.sections.builtin_actions(),
					starter.sections.recent_files(10, true),
					starter.sections.recent_files(10, false),
					-- Use this if you set up 'mini.sessions'
					-- starter.sections.sessions(),
					starter.sections.telescope(),
				},
				content_hooks = {
					starter.gen_hook.adding_bullet(),
					starter.gen_hook.padding(3, 2),
					starter.gen_hook.aligning("center", "center"),
				},
			})
			require("mini.bracketed").setup({
				{
					buffer = { suffix = "b", options = {} },
					comment = { suffix = "c", options = {} },
					conflict = { suffix = "", options = {} },
					diagnostic = { suffix = "d", options = {} },
					file = { suffix = "f", options = {} },
					indent = { suffix = "", options = {} }, -- disable since we use indentscope above
					jump = { suffix = "j", options = {} },
					location = { suffix = "l", options = {} },
					oldfile = { suffix = "o", options = {} },
					quickfix = { suffix = "q", options = {} },
					treesitter = { suffix = "t", options = {} },
					undo = { suffix = "", options = {} }, -- disable since I don't need it
					window = { suffix = "w", options = {} },
					yank = { suffix = "y", options = {} },
				},
			})
		end,
		event = "VimEnter", -- need to load pretty soon for Starter screen
		keys = {
			{ "<leader>sm", ":lua MiniMap.toggle()<cr>", { silent = true, desc = "minimap" } },
			{ "<leader>ss", ":lua MiniStarter.open()<cr>", { desc = "startpage" } },
			{
				"<localleader>w",
				function()
					require("mini.trailspace").trim()
				end,
			},
		},
	},
	-- try to avoid putting files in util buffers, e.g. filetree, aerial, undotree, ..
	{ "stevearc/stickybuf.nvim", config = true },
	-- make it a little less painful to open really big (>2mb) files by disabling features
	-- { "LunarVim/bigfile.nvim", lazy = false },
}
