local writing_ft = { "quarto", "pandoc", "markdown", "text", "tex" }

local prose_plugs = {
	-- UI improvements
	-- provide distraction free writing
	{
		"folke/zen-mode.nvim",
		config = true,
		cmd = { "ZenMode" },
		dependencies = { "folke/twilight.nvim" },
		keys = { { "<leader>sz", ":ZenMode<cr>", { silent = true } } },
	},
	{
		"andrewferrier/wrapping.nvim",
		opts = {
			create_keymappings = false,
			notify_on_switch = false,
			softener = { quarto = true, markdown = true, text = true, asciidoc = true },
			auto_set_mode_filetype_allowlist = {
				"asciidoc",
				"gitcommit",
				"latex",
				"mail",
				"markdown",
				"rst",
				"tex",
				"text",
				"quarto",
			},
		},
		event = { "BufReadPre", "BufNewFile" },
		keys = {
			{
				"<localleader>sw",
				function()
					require("wrapping").toggle_wrap_mode()
				end,
				silent = true,
				desc = "toggle wrap mode",
			},
		},
	},
	-- displays prettier headlines mimicking the ones in emacs orgmode
	{
		"lukas-reineke/headlines.nvim",
		dependencies = "nvim-treesitter/nvim-treesitter",
		config = true,
		ft = writing_ft,
	},
	-- generate an auto-updating html preview for md files
	{
		"iamcco/markdown-preview.nvim",
		build = function()
			vim.fn["mkdp#util#install"]()
		end,
		ft = writing_ft,
	},

	-- bring zettelkasten commands
	{
		"mickael-menu/zk-nvim",
		config = function()
			if require("util").is_available("which-key") then
				local prefix = require("which-key").register
				prefix({ ["<leader>n"] = { name = "+notes" } })
				prefix({ ["<localleader>n"] = { name = "+note" } })
				prefix({ ["<localleader>n"] = { name = "+note", mode = "v" } })

				require("zk.commands").add("ZkOrphans", function(opts)
					opts = vim.tbl_extend("force", { orphan = true }, opts or {})
					require("zk").edit(opts, { title = "Zk Orphans" })
				end)
			end
			require("zk").setup({ picker = "telescope" })
		end,
		ft = writing_ft,
		cmd = {
			"ZkBacklinks",
			"ZkCd",
			"ZkIndex",
			"ZkInsertLink",
			"ZkInsertLinkAtSelection",
			"ZkLinks",
			"ZkMatch",
			"ZkNew",
			"ZkNewFromContentSelection",
			"ZkNewFromTitleSelection",
			"ZkNotes",
			"ZkTags",
			"ZkOrphans",
		},
		keys = {
			{ "<leader>ni", "<cmd>edit ~/documents/notes/index.md<cr>", desc = "open index", silent = true },
			{ "<leader>nn", "<cmd>ZkNotes { sort = { 'modified' } }<cr>", desc = "note list" },
			{
				"<leader>nf",
				"<Cmd>ZkNotes { sort = { 'modified' }, match = { vim.fn.input('Search: ') } }<CR>",
				desc = "note search",
			},
			{ "<leader>nf", "<cmd>ZkMatch<cr>", desc = "find note from selection", mode = "v" },
			{ "<leader>nt", "<cmd>ZkTags<cr>", desc = "note tags" },
			{ "<leader>nc", "<cmd>ZkCd<cr>", desc = "notedir cd" },
			{ "<leader>no", "<cmd>ZkNotes { sort = { 'modified' } }<cr>", desc = "orphans list" },
			{ "<leader>nl", "<cmd>ZkLinks<cr>", desc = "note links" },
			{ "<leader>nb", "<cmd>ZkBacklinks<cr>", desc = "note backlinks" },
			{ "<localleader>nn", "<cmd>ZkNew { title = vim.fn.input('Title: ') }<cr>", desc = "new note" },
			{ "<localleader>nn", "<cmd>ZkNewFromTitleSelection<cr>", desc = "new note from selection", mode = "v" },
			{ "<localleader>nN", "<cmd>ZkNewFromContentSelection<cr>", desc = "content from selection", mode = "v" },
		},
	},

	-- syntax highlighting for markdown criticmarkup (comments, additions, ...)
	{ "vim-pandoc/vim-criticmarkup", ft = writing_ft },

	-- create mindmaps from your markdown
	{
		"Zeioth/markmap.nvim",
		cmd = { "MarkmapOpen", "MarkmapSave", "MarkmapWatch", "MarkmapWatchStop" },
		config = true,
	},

	-- cite as you write from papis databases
	-- ADDITIONAL DEPENDENCIES: papis and yq in shell env
	-- {
	-- 	"jghauser/papis.nvim",
	-- 	cond = vim.fn.executable("papis") == 1 and vim.fn.executable("yq") == 1,
	-- 	ft = writing_ft,
	-- 	dependencies = {
	-- 		"kkharji/sqlite.lua",
	-- 		"nvim-lua/plenary.nvim",
	-- 		"MunifTanjim/nui.nvim",
	-- 		"nvim-treesitter/nvim-treesitter",
	-- 	},
	-- 	lazy = false,
	-- 	config = true,
	-- }
}

return prose_plugs
